@@ -21,18 +21,21 @@ import aws_cdk.aws_events._jsii
 import aws_cdk.aws_iam._jsii
 import aws_cdk.aws_kms._jsii
 import aws_cdk.aws_lambda._jsii
+import aws_cdk.aws_logs._jsii
 import aws_cdk.aws_s3._jsii
 import aws_cdk.aws_sns._jsii
 import aws_cdk.aws_sqs._jsii
 import aws_cdk.aws_stepfunctions._jsii
 import aws_cdk.core._jsii
+import aws_cdk.custom_resources._jsii
+import aws_cdk.lambda_layer_awscli._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@aws-cdk/aws-stepfunctions-tasks",
-    "1.133.0",
+    "1.136.0",
     __name__[0:-6],
-    "aws-stepfunctions-tasks@1.133.0.jsii.tgz",
+    "aws-stepfunctions-tasks@1.136.0.jsii.tgz",
 )
 
 __all__ = [
